#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-module-system
version:              0.2.2.1
visibility:           public
id:                   hslua-module-system-0.2.2.1-CcUhULI5BJnRTr1tvagFf
key:                  hslua-module-system-0.2.2.1-CcUhULI5BJnRTr1tvagFf
license:              MIT
copyright:            © 2019-2020 Albert Krewinkel <albert+hslua@zeitkraut.de>
maintainer:           albert+hslua@zeitkraut.de
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua-module-system
synopsis:             Lua module wrapper around Haskell'\''s System module.
description:
    Provides access to system information and functionality
    to Lua scripts via Haskell'\''s `System` module.

    Intended usage for this package is to preload it by adding
    the loader function to `package.preload`. Note that the
    Lua `package` library must have already been loaded before
    the loader can be added.

category:             Foreign
abi:                  6580ce00544a22c21596fd8a9cae77da
exposed:              True
exposed-modules:      Foreign.Lua.Module.System
hidden-modules:       Foreign.Lua.Module.SystemUtils
import-dirs:          /usr/lib/ghc-8.10.4/site-local/hslua-module-system-0.2.2.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/hslua-module-system-0.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/i386-linux-ghc-8.10.4/hslua-module-system-0.2.2.1

hs-libraries:         HShslua-module-system-0.2.2.1-CcUhULI5BJnRTr1tvagFf
depends:
    base-4.14.1.0 containers-0.6.2.1 directory-1.3.6.0
    exceptions-0.10.4 hslua-1.3.0.1-AL5htsnGZdu3JCuXApKIHk
    temporary-1.3-G9Ct17Z0D7P1UdeEKugHmp

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-system/html/hslua-module-system.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-system/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

